#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 wl-pprint-extras
version:              3.5.0.5
visibility:           public
id:                   wl-pprint-extras-3.5.0.5-CXcV5mCM74l6x5mg0AkCKJ
key:                  wl-pprint-extras-3.5.0.5-CXcV5mCM74l6x5mg0AkCKJ
license:              BSD-3-Clause
copyright:
    Copyright (C) 2011-2012 Edward A. Kmett,
    Copyright (C) 2000 Daan Leijen

maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            experimental
homepage:             http://github.com/ekmett/wl-pprint-extras/
synopsis:             A free monad based on the Wadler/Leijen pretty printer
description:          A free monad based on the Wadler/Leijen pretty printer
category:             Control, Monads, Text
abi:                  2fbf0dd54b9fa0ff115421f3be47eb36
exposed:              True
exposed-modules:      Text.PrettyPrint.Free Text.PrettyPrint.Free.Internal
import-dirs:          /usr/lib/ghc-8.10.5/site-local/wl-pprint-extras-3.5.0.5
library-dirs:         /usr/lib/ghc-8.10.5/site-local/wl-pprint-extras-3.5.0.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/i386-linux-ghc-8.10.5/wl-pprint-extras-3.5.0.5
hs-libraries:         HSwl-pprint-extras-3.5.0.5-CXcV5mCM74l6x5mg0AkCKJ
depends:
    base-4.14.2.0 containers-0.6.4.1
    semigroupoids-5.3.5-CXCAmgAqO2AH1F4bh8bCjo text-1.2.4.1
    utf8-string-1.0.2-DMovLmOdbFr3ZT2kNNb9Du

haddock-interfaces:
    /usr/share/doc/haskell-wl-pprint-extras/html/wl-pprint-extras.haddock

haddock-html:         /usr/share/doc/haskell-wl-pprint-extras/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

